from ramda.private.asserts import *
from ramda.test import test


def test_test():
    assert_equal(test(r"^x", "xyz"), True)
    assert_equal(test(r"^y", "xyz"), False)
